.. HDX Python Utilities documentation master.

HDX Python Utilities Documentation
==================================

The HDX Python Utilities Library provides some helpful utilities eg. downloading files, emailing.

Contents
--------

.. toctree::
   :maxdepth: 1

   source/hdx.utilities.rst

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

